summaryrefslogtreecommitdiffstats
path: root/linux/LinuxProcessList.c
diff options
context:
space:
mode:
authorBenny Baumann <BenBE@geshi.org>2021-04-10 13:31:39 +0200
committerBenBE <BenBE@geshi.org>2021-05-23 09:22:21 +0200
commitbcb18ef82269c68d54a160290e5f8b2e939674ec (patch)
treee5967c038b2d11ed906b8fdda0babe114dab3c46 /linux/LinuxProcessList.c
parentc0d02024407411f75a4d7d5b63f26b74c727027b (diff)
Move Process_makeCommandStr to global Process implementation
Diffstat (limited to 'linux/LinuxProcessList.c')
-rw-r--r--linux/LinuxProcessList.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/linux/LinuxProcessList.c b/linux/LinuxProcessList.c
index 020fc0a5..ca2f2b80 100644
--- a/linux/LinuxProcessList.c
+++ b/linux/LinuxProcessList.c
@@ -1028,7 +1028,7 @@ static bool LinuxProcessList_readCmdlineFile(Process* process, openat_arg_t proc
for (int i = 0; i < amtRead; i++) {
/* newline used as delimiter - when forming the mergedCommand, newline is
* converted to space by LinuxProcess_makeCommandStr */
if (command[i] == '\0') {
command[i] = '\n';
} else {
@@ -1432,7 +1432,7 @@ static bool LinuxProcessList_recurseProcTree(LinuxProcessList* this, openat_arg_
if (!Process_isKernelThread(proc) &&
(proc->state != 'Z' || proc->mergedCommand.str) &&
(!Process_isUserlandThread(proc) || !settings->showThreadNames)) {
- LinuxProcess_makeCommandStr(proc);
+ Process_makeCommandStr(proc);
}
#ifdef HAVE_DELAYACCT
@@ -1028,7 +1028,7 @@ static bool LinuxProcessList_readCmdlineFile(Process* process, openat_arg_t proc
for (int i = 0; i < amtRead; i++) {
/* newline used as delimiter - when forming the mergedCommand, newline is
- * converted to space by LinuxProcess_makeCommandStr */
+ * converted to space by Process_makeCommandStr */
if (command[i] == '\0') {
command[i] = '\n';

© 2014-2024 Faster IT GmbH | imprint | privacy policy